log

package
v0.3.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 7, 2026 License: BSD-3-Clause Imports: 2 Imported by: 0

Documentation

Overview

Package log defines the logger interface used in rsync library.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Logger

type Logger interface {
	// Printf logs message to the underlying log output. Arguments are handled in the manner of fmt.Printf.
	Printf(msg string, a ...any)

	Output(calldepth int, s string) error
}

Logger is an interface that allows specifying your own logger. By default, the Go log package is used, which prints to stderr.

func New added in v0.2.3

func New(out io.Writer) Logger

Jump to